Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateLogger ¶
func CreateLogger(options Options) (gen.LoggerBehavior, error)
Types ¶
type Options ¶
type Options struct {
// TimeFormat enables output time in the defined format. See https://pkg.go.dev/time#pkg-constants
// Not defined format makes output time as a timestamp in nanoseconds.
TimeFormat string
// IncludeBehavior includes process/meta behavior to the log message
IncludeBehavior bool
// IncludeName includes registered process name to the log message
IncludeName bool
// IncludeFields includes associated fields to the log message
IncludeFields bool
// ShortLevelName enables shortnames for the log levels
ShortLevelName bool
// DisableBanner disables Ergo logo on start
DisableBanner bool
}
Click to show internal directories.
Click to hide internal directories.